## ************************************************************************** ##
## *************             BittWare Incorporated              ************* ##
## *************         9 Hills Ave, Concord, NH 03301         ************* ##
## ************************************************************************** ##
## LEGAL NOTICE:                                                              ##
##                   Copyright (c) 2011 BittWare, Inc.                        ##
##     The user is hereby granted a non-exclusive license to use and or       ##
##       modify this code provided that it runs on BittWare hardware.         ##
##     Usage of this code on non-BittWare hardware without the express        ##
##        written permission of BittWare is strictly prohibited.              ##
##                                                                            ##
##  E-mail: support@bittware.com                    Tel: 603-226-0404         ##
## ************************************************************************** ##
## ABSTRACT:
## ************************************************************************** ##
## DESIGN NOTES:
## All procedures that begin with user_ are called directly at discrete points
## by the afw.tcl script.  These procedures must exist in this file.
## ************************************************************************** ##

################################################################################
# call sequence: first
# set up the project_info structure
################################################################################
proc user_setup_project { afw } {
  set project_info [$afw get_project_info_name]

  $project_info set project_description \
    "This component group provides an example component demonstrating the typical\
     component interfaces, register bank configuration and Avalon-ST data path\
     with flow control support. It also provides and example sub-system that moves\
     streaming data in and out of memory mapped locations."

  $project_info set project_status "RELEASE"

  # Add toplevel name to output directory name
  $project_info set config_dir_mode "toplevel_prefix"

  # Set default toplevel and config
  $project_info set toplevel    "tb_ExampleComponent"
  $project_info set config_name "cfg_0"
}

################################################################################
# call sequence: second
# set up the config_info structure
################################################################################
proc user_setup_config { afw } {
  set project_info [$afw get_project_info_name]
  set config_info  [$afw get_config_info_name]
  set toplevel     [$project_info get toplevel]
  set config_name  [$project_info get config_name]

  if {[string equal -nocase $toplevel "tb_ExampleComponent"]} {
    if {[string equal -nocase $config_name "cfg_0"]} {
    } else {
      log info "Using a custom configuration ($config_name)"
    }
  } else {
    log error "Unsupported $toplevel toplevel!"
  }
}

################################################################################
# call sequence: third
# set up the derived_info structure
################################################################################
proc user_setup_derived { afw } {
}

################################################################################
# call sequence: fourth
# configure the board resources
################################################################################
proc user_setup_resource_map { afw } {
  set resource_map [list]
  # Save the resource map.  This should always be here
  $afw save_resource_map $resource_map
}

################################################################################
# call sequence: fifth
# manage all the files in the project
################################################################################
proc user_use_units { afw } {
  set board_info   [$afw get_board_info_name]
  set project_info [$afw get_project_info_name]
  set board_name   [$board_info get name]

  $afw use_components lib
  $afw use_boards     lib {all} lib
  $afw use_components {misc register_bank fifo memory memory_mapped arbiter \
                       streaming dma sub_system simulation example }
  $afw use_components example {all} tb
}

################################################################################
# call sequence: sixth
# write to the project configuration package
################################################################################
proc user_setup_package { afw } {
  set config_info [$afw get_config_info_name]

  $afw vhdl_set_board_info
}

################################################################################
# The user must generate the code for the auto_sdc file here
################################################################################
proc user_auto_sdc { afw } {
}

################################################################################
# The user must generate the code for the auto_loc file here
################################################################################
proc user_auto_loc { afw } {
}

################################################################################
# The procedures with the prefix "user_after_" are called during the writing of
# the auto generated tcl file.  They give the user the ability to modify the
# file directly.  Use the write_auto_syn method in these procedures to write to
# the file.
# Only applies to auto_syn.tcl
################################################################################

################################################################################
# call sequence: seventh
################################################################################
proc user_after_header { afw } {
}

################################################################################
# call sequence: eighth
################################################################################
proc user_after_resource_map { afw } {
}

################################################################################
# call sequence: ninth
################################################################################
proc user_after_files { afw } {
}

################################################################################
# call sequence: tenth
################################################################################
proc user_after_config { afw } {
}
